@@ -24,7 +24,8 @@ archive_results = TRUE
 # http://presentation.ubiquity.grok.tv
 
 # Rebuilding the system (R scripts and compiling C code)
-cfg = build_system()
+cfg = build_system(output_directory     = file.path(".", "output"),
+                   temporary_directory  = file.path(".", "transient"))
 
 # set name                  | Description
 # -------------------------------------------------------
@@ -54,41 +55,81 @@ cfg = system_clear_cohorts(cfg)
 
 #-------------------------------------------------------
 # 10 mpk cohort
-cohort  = c()
-cohort$name                                   = 'dose_10'
-cohort$dataset                                = 'pm_data'
-cohort$cf$DOSE                                = c(10)
-cohort$inputs$bolus$Mpb$AMT                   = c(10)
-cohort$inputs$bolus$Mpb$TIME                  = c(0)
-cohort$outputs$Parent$obs$time                = 'TIME'
-cohort$outputs$Parent$obs$value               = 'PT'
-cohort$outputs$Parent$obs$missing             = -1
-cohort$outputs$Parent$model$time              = 'hours'
-cohort$outputs$Parent$model$value             = 'Cpblood'
-cohort$outputs$Parent$model$variance          = '1'
-cohort$outputs$Parent$options$marker_color    = 'black'   
-cohort$outputs$Parent$options$marker_shape    = 1
-cohort$outputs$Parent$options$marker_line     = 2
+
+cohort = list(
+  name         = "dose_10",
+  cf           = list(DOSE      = c(10)),
+  inputs       = NULL,
+  outputs      = NULL,
+  dataset      = "pm_data")
+
+# Bolus inputs for the cohort
+cohort[["inputs"]][["bolus"]] = list()
+cohort[["inputs"]][["bolus"]][["Mpb"]] = list(TIME=NULL, AMT=NULL)
+cohort[["inputs"]][["bolus"]][["Mpb"]][["TIME"]] = c( 0) # hours 
+cohort[["inputs"]][["bolus"]][["Mpb"]][["AMT"]]  = c(10) # mpk 
+
+
+# Defining Parent output
+cohort[["outputs"]][["Parent"]] = list()
+
+# Mapping to data set
+cohort[["outputs"]][["Parent"]][["obs"]] = list(
+         time           = "TIME",
+         value          = "PT",
+         missing        = -1)
+
+# Mapping to system file
+cohort[["outputs"]][["Parent"]][["model"]] = list(
+         time           = "hours",       
+         value          = "Cpblood",   
+         variance       = "1")
+
+# Plot formatting
+cohort[["outputs"]][["Parent"]][["options"]] = list(
+         marker_color   = "black",
+         marker_shape   = 1,
+         marker_line    = 2 )
+
 cfg = system_define_cohort(cfg, cohort)
 #-------------------------------------------------------
 
 #-------------------------------------------------------
 # 30 mpk cohort
-cohort  = c()
-cohort$name                                   = 'dose_30'
-cohort$dataset                                = 'pm_data'
-cohort$cf$DOSE                                = c(30)
-cohort$inputs$bolus$Mpb$AMT                   = c(30)
-cohort$inputs$bolus$Mpb$TIME                  = c(0)
-cohort$outputs$Parent$obs$time                = 'TIME'
-cohort$outputs$Parent$obs$value               = 'PT'
-cohort$outputs$Parent$obs$missing             = -1
-cohort$outputs$Parent$model$time              = 'hours'
-cohort$outputs$Parent$model$value             = 'Cpblood'
-cohort$outputs$Parent$model$variance          = '1'
-cohort$outputs$Parent$options$marker_color    = 'red'   
-cohort$outputs$Parent$options$marker_shape    = 2
-cohort$outputs$Parent$options$marker_line     = 2
+cohort = list(
+  name         = "dose_30",
+  cf           = list(DOSE      = c(30)),
+  dataset      = "pm_data",
+  inputs       = NULL,
+  outputs      = NULL)
+
+# Bolus inputs for the cohort
+cohort[["inputs"]][["bolus"]] = list()
+cohort[["inputs"]][["bolus"]][["Mpb"]] = list(TIME=NULL, AMT=NULL)
+cohort[["inputs"]][["bolus"]][["Mpb"]][["TIME"]] = c( 0) # hours 
+cohort[["inputs"]][["bolus"]][["Mpb"]][["AMT"]]  = c(30) # mpk 
+
+
+# Defining Parent output
+cohort[["outputs"]][["Parent"]] = list()
+
+# Mapping to data set
+cohort[["outputs"]][["Parent"]][["obs"]] = list(
+         time           = "TIME",
+         value          = "PT",
+         missing        = -1)
+
+# Mapping to system file
+cohort[["outputs"]][["Parent"]][["model"]] = list(
+         time           = "hours",       
+         value          = "Cpblood",   
+         variance       = "1")
+
+# Plot formatting
+cohort[["outputs"]][["Parent"]][["options"]] = list(
+         marker_color   = "red",
+         marker_shape   = 2,
+         marker_line    = 2 )
 
 cfg = system_define_cohort(cfg, cohort)
 #-------------------------------------------------------
